Crate arora_module_rust

Crate arora_module_rust 

Modules

rustfmt

Structs

RawUuidValue
A helper to format a Uuid into an inlined byte array.

Enums

CheckType
GenerationError
PrefixWithMod
Public

Functions

enum_variant_const_id_ident
enum_variant_ident
function_const_id_ident
function_param_const_id_ident
generate_common_sources
generate_const_id_declaration
Generates the const declaration of the ID associated to the given name (and ident).
generate_enumeration_source
Generates a Rust source file for the given enumeration. It contains the type declaration and some functions to serialize and deserialize values. It depends on arora_buffers, arora_types and uuid.
generate_into_impl
generate_mods_in_directories
Generates mod.rs files and adds them at every level of the directory hierarchy where .rs files can be found. Returns true if it was generated.
generate_records
Generates YAML record files alongside a records.json index from the type assets produced by arora_module_core::analyze_module. Must be called BEFORE generate_sources because generate_sources consumes assets.
generate_sources
Generates a set of sources organized in a virtual directory from a set of assets as produced by arora_module_core::analyze_module. First, the types, then the modules, then the imports.
generate_structure_source
Generates a Rust source file for the given structure. It contains the type declaration and some functions to serialize and deserialize values. It depends on arora-buffers, arora-types, arora-registry and uuid.
generate_try_from_impl
struct_field_const_id_ident
struct_field_ident
struct_field_intermediate_variable_ident
token_stream_to_file
type_ident
variable_ident