generate_enumeration_source

Function generate_enumeration_source 

pub fn generate_enumeration_source(
    id: &Uuid,
    enumeration: &EnumerationFrozen,
    parent_path: &str,
) -> Result<Directory, VfsError>
Generates a Rust source file for the given enumeration. It contains the type declaration and some functions to serialize and deserialize values. It depends on arora_buffers, arora_types and uuid.