generate_structure_source

Function generate_structure_source 

pub async fn generate_structure_source(
    id: &Uuid,
    structure: &StructureFrozen,
    registry: &mut dyn ReadableRegistry,
    parent_path: &str,
) -> Result<Directory, GenerationError>
Generates a Rust source file for the given structure. It contains the type declaration and some functions to serialize and deserialize values. It depends on arora-buffers, arora-types, arora-registry and uuid.