Module rustfmt

Module rustfmt 

Functions

apply_rustfmt
Run rustfmt on all Rust files found under the given path.
list_all_files
Helper to list all files recursively under the given path, while filtering result (files only) with a custom predicate.