Modules
Structs
- RawUuid
Value - A helper to format a Uuid into an inlined byte array.
Enums
Functions
- enum_
variant_ const_ id_ ident - enum_
variant_ ident - function_
const_ id_ ident - function_
param_ const_ id_ ident - generate_
common_ sources - generate_
const_ id_ declaration - Generates the const declaration of the ID associated to the given name (and ident).
- generate_
enumeration_ source - Generates a Rust source file for the given enumeration.
It contains the type declaration and some functions
to serialize and deserialize values.
It depends on
arora_buffers,arora_typesanduuid. - generate_
into_ impl - generate_
mods_ in_ directories - Generates
mod.rsfiles and adds them at every level of the directory hierarchy where.rsfiles can be found. Returns true if it was generated. - generate_
records - Generates YAML record files alongside a
records.jsonindex from the type assets produced byarora_module_core::analyze_module. Must be called BEFOREgenerate_sourcesbecausegenerate_sourcesconsumesassets. - generate_
sources - Generates a set of sources organized in a virtual directory
from a set of assets as produced by
arora_module_core::analyze_module. First, the types, then the modules, then the imports. - generate_
structure_ source - Generates a Rust source file for the given structure.
It contains the type declaration and some functions
to serialize and deserialize values.
It depends on
arora-buffers,arora-types,arora-registryanduuid. - generate_
try_ from_ impl - struct_
field_ const_ id_ ident - struct_
field_ ident - struct_
field_ intermediate_ variable_ ident - token_
stream_ to_ file - type_
ident - variable_
ident