generate_sources

Function generate_sources 

pub async fn generate_sources(
    assets: Vec<ModuleAsset>,
    registry: &mut dyn ReadableRegistry,
) -> Result<Directory, GenerationError>
Generates a set of sources organized in a virtual directory from a set of assets as produced by arora_module_core::analyze_module. First, the types, then the modules, then the imports.