Functions
- apply_
rustfmt - Run
rustfmton all Rust files found under the given path. - list_
all_ files - Helper to list all files recursively under the given path, while filtering result (files only) with a custom predicate.
rustfmt on all Rust files found under the given path.